# Sources

Boostrap version 2.3.2 has been downloaded from:

https://maxcdn.bootstrapcdn.com/bootstrap/2.3.2/css/bootstrap.css

Bootstrap's documentation styles has been downloaded from:

http://getbootstrap.com/2.3.2/assets/css/docs.css
